//
//  ViewController.m
//  MultiLineGraph
//
//  Created by Caylan Larson on 11/5/14.
//  Copyright (c) 2014 Caylan Larson. All rights reserved.
//

#import "ViewController.h"

@interface ViewController ()
@property (strong, nonatomic) NSMutableArray *dataAverage;
@property (strong, nonatomic) NSMutableArray *dataMin;
@property (nonatomic) NSInteger nextIndex;
@end

@implementation ViewController

- (void)viewDidLoad
{
    [IGChartView class];
    [super viewDidLoad];
    
    BOOL bugfix = YES;
    
    if(bugfix)
    {
        self.dataAverage = [@[ [self pointWithRelativeTimeInterval:0 value:1] ] mutableCopy];
        self.dataMin = [@[ [self pointWithRelativeTimeInterval:0 value:1] ] mutableCopy];
    }
    else
    {
        self.dataAverage = [NSMutableArray new];
        self.dataMin = [NSMutableArray new];
    }
    
    self.nextIndex = self.dataAverage.count;
    
    [self.chart addSeriesForType:[IGLineSeries class] usingKey:@"average" withDataSource:self firstAxisKey:@"date" secondAxisKey:@"value"];
    [self.chart addSeriesForType:[IGLineSeries class] usingKey:@"min" withDataSource:self firstAxisKey:@"date" secondAxisKey:@"value"];
    
    [self.chart addAxis:[[IGCategoryXAxis alloc] initWithKey:@"x"]];
    [self.chart addAxis:[[IGNumericYAxis alloc] initWithKey:@"y"]];
}

-(void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    [self addNewData];
}

-(void)addNewData
{
    [self.dataAverage addObject:[self pointWithRelativeTimeInterval:self.nextIndex value:(arc4random() % 50)]];
    [self.dataMin addObject:[self pointWithRelativeTimeInterval:self.nextIndex value:(arc4random() % 50)]];
    [self.chart insertItemAtIndex:self.nextIndex withSource:self];

    self.nextIndex++;
    
    [self performSelector:@selector(addNewData) withObject:nil afterDelay:0.5];
}

-(NSInteger)numberOfPointsInSeries:(IGSeries *)series
{
    NSInteger count = 0;
    if([series.key isEqualToString:@"average"])
    {
        count = self.dataAverage.count;
    }
    else if([series.key isEqualToString:@"min"])
    {
        count = self.dataMin.count;
    }
    
    return count;
}

-(IGDataPoint*)series:(IGSeries *)series pointAtIndex:(NSInteger)index
{
    IGDataPoint *point = nil;
    
    if([series.key isEqualToString:@"average"])
    {
        point = self.dataAverage[index];
    }
    else if([series.key isEqualToString:@"min"])
    {
        point = self.dataMin[index];
    }
    
    return point;
}

-(IGCategoryDatePoint*)pointWithRelativeTimeInterval:(NSTimeInterval)timeInterval value:(CGFloat)value
{
    NSDate *date = [NSDate dateWithTimeIntervalSince1970:timeInterval];
    return [[IGCategoryDatePoint alloc] initWithValue:value andDate:date andLabel:date.description];
}

@end
